@@ -1,31 +1,46 @@
 # -*- coding: utf-8 -*-
 """
+..
     SmartHTTP 
-    Release 0.4 rev. 123 on 2010-04-14 09:33:33.212723
-    Copyright (C) Thu Aug 27 04:01:12 2009 +1100-Wed Apr 14 20:33:28 2010 +1100,
+    Release 0.5 rev. 279 on 2010-07-20 04:32:27.374371
+    Copyright (C) 2009-2010,
     Authors: Dan Kluev <dan@kluev.name>
 
     Module smarthttp.envspec.http
-    Module for loading interpreter-specific HTTP handling code
-    Last changed on Wed Apr 14 14:50:37 2010 +1100 rev. 111:5efdacc70dde by Dan Kluev <orion@ssorion.info>
+    Interpreter-specific HTTP
+    Last changed on 2010-05-16 12:15:09+11:00 rev. 184:f0b05c264948 by Dan Kluev <orion@ssorion.info>
 
+..
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-
+    
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
+    
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+
+Interpreter-specific HTTP
+=========================
 """
-import smarthttp.envspec as envspec
+__docformat__ = 'restructuredtext'
+
+from . import interpreter
+if interpreter == 'CPython':
+    from .cpython import http
+elif interpreter == 'Jython':
+    from .jython import http
+else:
+    from .pure import http
+
 import types
 ldict = locals()
-for k in envspec.http.__dict__:
-    v = envspec.http.__dict__[k]
-    if type(v) == types.FunctionType or type(v) == types.ClassType:
+for k in http.__dict__:
+    v = http.__dict__[k]
+    if not k.startswith('__') or not k.endswith('__'):
         ldict[k] = v
