@@ -1,24 +1,43 @@
 # -*- coding: utf-8 -*-
 """
+..
     SmartHTTP 
-    Release 0.4 rev. 123 on 2010-04-14 09:33:33.212723
-    Copyright (C) Thu Aug 27 04:01:12 2009 +1100-Wed Apr 14 20:33:28 2010 +1100,
+    Release 0.5 rev. 279 on 2010-07-20 04:32:27.374371
+    Copyright (C) 2009-2010,
     Authors: Dan Kluev <dan@kluev.name>
 
     Module smarthttp.lib
     Some additional libraries
-    Last changed on Wed Apr 14 14:50:37 2010 +1100 rev. 111:5efdacc70dde by Dan Kluev <orion@ssorion.info>
+    Last changed on 2010-05-21 20:04:13+11:00 rev. 219:eb74038dbda0 by Dan Kluev <orion@ssorion.info>
 
+..
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-
+    
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
+    
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+
+Some additional libraries
+=========================
+
+.. toctree::
+   :hidden:
+
+   smarthttp.lib.containers
+
+:mod:`smarthttp.lib.containers`
+:mod:`smarthttp.lib.simplebot`
+:mod:`smarthttp.lib.httpbot`
+:mod:`smarthttp.lib.pylonsscript`
+
 """
+
+__docformat__ = 'restructuredtext'
