@@ -1,35 +1,53 @@
 # -*- coding: utf-8 -*-
 """
+..
     SmartHTTP 
-    Release 0.4 rev. 123 on 2010-04-14 09:33:33.212723
-    Copyright (C) Thu Aug 27 04:01:12 2009 +1100-Wed Apr 14 20:33:28 2010 +1100,
+    Release 0.5 rev. 279 on 2010-07-20 04:32:27.374371
+    Copyright (C) 2009-2010,
     Authors: Dan Kluev <dan@kluev.name>
 
     Module smarthttp.proxies
     Proxy managers and handlers
-    Last changed on Wed Apr 14 16:23:22 2010 +1100 rev. 118:18d39f1107c7 by Dan Kluev <orion@ssorion.info>
+    Last changed on 2010-05-29 00:41:07+11:00 rev. 249:c664b92c9e32 by Dan Kluev <dan@kluev.name>
 
+..
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-
+    
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
+    
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+
+Proxy managers and handlers
+===========================
+
 Should implement:
 1. Proxy manager - keeps proxy stats, rotates proxies between clients
 2. Proxy protocol implementations (HTTP, SOCKS4/5, CGI proxies)
 3. Implementation of proxy chains
 
+.. _smarthttp.proxies-ProxyManager:
+
+:class:`ProxyManager`
+---------------------
+
+
+
+.. autoclass:: ProxyManager
+    :members:
+    :undoc-members:
+
 """
+__docformat__ = 'restructuredtext'
 
 class ProxyManager(object):
-   pass
+    pass
 
 
